@@ -40,7 +40,7 @@ class KinesisDestination(
         '''
         :param stream: -
         '''
-        jsii.create(KinesisDestination, self, [stream])
+        jsii.create(self.__class__, self, [stream])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -83,7 +83,7 @@ class LambdaDestination(
         '''
         options = LambdaDestinationOptions(add_permissions=add_permissions)
 
-        jsii.create(LambdaDestination, self, [fn, options])
+        jsii.create(self.__class__, self, [fn, options])
 
     @jsii.member(jsii_name="bind")
     def bind(
